# CHANGELOG



## v0.20.0 (2024-01-13)

### Feature

* feat: select from 10 most recent issues (issue #71) (#72)

Fixes #71 ([`3ec5c56`](https://github.com/MartinBernstorff/herbarium/commit/3ec5c568fddc708aef5caf91031a16827ef66957))

### Refactor

* refactor: misc. (#116)

refactor: misc.

refactor: misc. ([`d812453`](https://github.com/MartinBernstorff/herbarium/commit/d812453ffc5bc89808586f383cf443386ff2b983))

### Unknown

* misc. ([`d0cadbd`](https://github.com/MartinBernstorff/herbarium/commit/d0cadbd4d782f2f6a2c74b163d3bb549f0e206dd))

* misc. ([`dbf38cc`](https://github.com/MartinBernstorff/herbarium/commit/dbf38cc9b552a223c2e72d7da451656d26666042))

* misc. ([`5e7bbca`](https://github.com/MartinBernstorff/herbarium/commit/5e7bbca305e563164008cf08582477959b531e38))

* misc. ([`19436ef`](https://github.com/MartinBernstorff/herbarium/commit/19436ef65aa473b17e4162420ca67e799fae390d))

* dev: allow-skipping-sync-on-herb-add (#117)

dev: allow-skipping-sync-on-herb-add

dev: allow-skipping-sync-on-herb-add

misc. ([`d8979fd`](https://github.com/MartinBernstorff/herbarium/commit/d8979fdd0b7861a3ffb3684363d913dd8ef37ef5))

* misc. ([`642199e`](https://github.com/MartinBernstorff/herbarium/commit/642199e87536500282dfe3c8a4de805b84a131c2))

* dev: allow-skipping-sync-on-herb-add ([`d99a48c`](https://github.com/MartinBernstorff/herbarium/commit/d99a48c1fa14e88668e1da99641932e3d42fa79e))


## v0.19.0 (2024-01-13)

### Feature

* feat(#110): on-submit-mark-issue-as-in-progress (#112)

feat(#110): on-submit-mark-issue-as-in-progress

Fixes #110

misc.

misc ([`d33c4c8`](https://github.com/MartinBernstorff/herbarium/commit/d33c4c8df0690afb279219034e21c3d79eb8b3bf))

* feat(#110): on-submit-mark-issue-as-in-progress

Fixes #110 ([`81eb964`](https://github.com/MartinBernstorff/herbarium/commit/81eb964992e66c78e704dc500468b99b0276c33e))

### Fix

* fix: correct issue selection ([`0cb5cf9`](https://github.com/MartinBernstorff/herbarium/commit/0cb5cf9795eddf849950608e63bddc668b21aee0))

### Refactor

* refactor: misc. ([`61e8422`](https://github.com/MartinBernstorff/herbarium/commit/61e8422357633c0cce9365fe0d000c9ee4f630ab))

### Unknown

* misc. ([`fd4a4b0`](https://github.com/MartinBernstorff/herbarium/commit/fd4a4b0ef172cea86f4c2facd7be67ff73f904ea))

* misc ([`61e435d`](https://github.com/MartinBernstorff/herbarium/commit/61e435d024dd7177806424e136ac9759456bf709))

* misc. ([`49645da`](https://github.com/MartinBernstorff/herbarium/commit/49645da267e3678c02882957729c0ce222833992))

* dev: automatically-submit-and-ask-for-next-issue (#109)

dev: automatically-submit-and-ask-for-next-issue

dev: automatically-submit-and-ask-for-next-issue ([`8a83dd9`](https://github.com/MartinBernstorff/herbarium/commit/8a83dd97d2bf4b277f09aba966688556f5f369cf))

* dev: automatically-submit-and-ask-for-next-issue ([`1f8fa3a`](https://github.com/MartinBernstorff/herbarium/commit/1f8fa3a9194ce19f3686a1b885c94bc94d19a624))


## v0.18.0 (2024-01-13)

### Feature

* feat: delete-merged-branches-on-sync (#108)

feat: delete-merged-branches-on-sync

feat: delete-merged-branches-on-sync ([`c2ed5d8`](https://github.com/MartinBernstorff/herbarium/commit/c2ed5d8f04cf4008e6fe6474a7a0fed96136ddd6))

* feat: delete-merged-branches-on-sync ([`9822bd7`](https://github.com/MartinBernstorff/herbarium/commit/9822bd79b535d87b7586f5bdb73eecb5ea99c559))


## v0.17.0 (2024-01-13)

### Feature

* feat(#103): support-aliases-for-commands-and-locations (#106)

feat(#103): support-aliases-for-commands-and-locations

Fixes #103

misc.

misc.

misc. ([`a18d976`](https://github.com/MartinBernstorff/herbarium/commit/a18d9769da412fa069b50467d65b7e1c06b83ffb))

### Fix

* fix(#104): automerge-is--merge-when-ready-in-graphite (#107)

fix(#104): automerge-is--merge-when-ready-in-graphite

Fixes #104

misc. ([`d587bf4`](https://github.com/MartinBernstorff/herbarium/commit/d587bf4770417104ced54a380ec75a752fad3eb8))

### Unknown

* misc. ([`5259014`](https://github.com/MartinBernstorff/herbarium/commit/5259014481d7c4f00d6b366580b9950fc7b36fd5))


## v0.16.0 (2024-01-13)

### Feature

* feat(#103): support-aliases-for-commands-and-locations

Fixes #103 ([`e6c88a5`](https://github.com/MartinBernstorff/herbarium/commit/e6c88a52f820f30e5e7978581e981b7d13c0b045))

* feat: implement-new-vocabulary (#102)

feat: implement-new-vocabulary

misc.

misc.

misc.

misc.

misc.

misc.

misc.

misc.

misc.

lint

misc. ([`3f15589`](https://github.com/MartinBernstorff/herbarium/commit/3f15589dcebed46ab106b2353540fb9be04956ec))

* feat: implement-new-vocabulary ([`8a09bde`](https://github.com/MartinBernstorff/herbarium/commit/8a09bde24b0c3234df0ca9640efb22e42d8811e7))

### Unknown

* misc. ([`f7520f5`](https://github.com/MartinBernstorff/herbarium/commit/f7520f576b4e754014cca85e53540ed186c41778))

* misc. ([`479b68c`](https://github.com/MartinBernstorff/herbarium/commit/479b68ca452f04429370e74ee5a960ed510879d2))

* misc. ([`241be46`](https://github.com/MartinBernstorff/herbarium/commit/241be460e46f93ff8cca4a0d633b696d4784e3ec))

* misc. ([`bfce67f`](https://github.com/MartinBernstorff/herbarium/commit/bfce67f564238773188e46ffb3027aed692f6895))

* misc. ([`f1bbed8`](https://github.com/MartinBernstorff/herbarium/commit/f1bbed8c8a2a6c830d2947f0464396e54ec2eee8))

* misc. ([`6c9b0df`](https://github.com/MartinBernstorff/herbarium/commit/6c9b0dfb2337898575ec1827881c85c878fdfe86))

* misc. ([`ab08fdf`](https://github.com/MartinBernstorff/herbarium/commit/ab08fdfc6c9b46077bbc299513bd8676ae3d427a))

* lint ([`5db9b57`](https://github.com/MartinBernstorff/herbarium/commit/5db9b57248b976f4922f9d64cf949b9b49de34b6))

* misc. ([`e11c540`](https://github.com/MartinBernstorff/herbarium/commit/e11c5402f40bfdc7af20353d05fe8fc292af4b0a))

* misc. ([`7d5bb3a`](https://github.com/MartinBernstorff/herbarium/commit/7d5bb3a79d78e05da70e4a5984e13691d276e5d4))

* misc. ([`b7a52c8`](https://github.com/MartinBernstorff/herbarium/commit/b7a52c81c13aed9a67019e5b0d8847a6214dd440))

* misc. ([`2726f85`](https://github.com/MartinBernstorff/herbarium/commit/2726f8519c3ee2137e872f673b5a1c38dfc4f886))

* misc. ([`3311ecb`](https://github.com/MartinBernstorff/herbarium/commit/3311ecbcb5fde71fa1789b8847fb84c27b0f445d))

* misc. ([`867d3a5`](https://github.com/MartinBernstorff/herbarium/commit/867d3a52500a444a515ac9c86f76746aa6dff98f))

* misc. ([`a50158c`](https://github.com/MartinBernstorff/herbarium/commit/a50158cfc38c4fb61cc699846a42e03dade3e1eb))

* misc. ([`7741123`](https://github.com/MartinBernstorff/herbarium/commit/7741123fbcb3642f93e24eb72210ca23856a3db6))

* misc. ([`9f6d5e8`](https://github.com/MartinBernstorff/herbarium/commit/9f6d5e823770706a67634021beb4c77147f7c47f))


## v0.15.0 (2024-01-13)

### Feature

* feat: implement-QueueNavigator (#101)

feat: implement-QueueNavigator

misc.

misc. ([`2de54db`](https://github.com/MartinBernstorff/herbarium/commit/2de54dbf1fc06933623bea3cba54268dca87d5b5))


## v0.14.0 (2024-01-13)

### Feature

* feat: implement-QueueNavigator ([`c69f2df`](https://github.com/MartinBernstorff/herbarium/commit/c69f2dfdb11f458ae6748c9f997a721713448c6a))

* feat(#91): implement-go-to-front (#100)

feat(#91): implement-go-to-front

Fixes #91

misc.

misc. ([`50bd9fe`](https://github.com/MartinBernstorff/herbarium/commit/50bd9fe79a3ff91d5dc9c348b3d5e7780a857d16))

* feat(#91): implement-go-to-front

Fixes #91 ([`d9dd1a9`](https://github.com/MartinBernstorff/herbarium/commit/d9dd1a96a0bd80faabc055f0536a6e957ba33239))

### Unknown

* misc. ([`a3ca5c4`](https://github.com/MartinBernstorff/herbarium/commit/a3ca5c44eef75143ddfc1c5495c573bbbe2b7fcd))

* misc. ([`fa933e9`](https://github.com/MartinBernstorff/herbarium/commit/fa933e94edb99ea9a2115d1d36f7a6bb608845c0))

* misc. ([`ce80502`](https://github.com/MartinBernstorff/herbarium/commit/ce80502073bccc1daa0fd5513d782c44479dbd5f))

* misc. ([`49eb56f`](https://github.com/MartinBernstorff/herbarium/commit/49eb56f864a3b37df4872b88425353a0843fbe1b))


## v0.13.1 (2024-01-10)

### Performance

* perf: no-need-to-sync-before-submit (#87)

perf: no-need-to-sync-before-submit

perf: no-need-to-sync-before-submit ([`4662466`](https://github.com/MartinBernstorff/herbarium/commit/466246653124cdc31462c97b73eea22eba43dc9b))

* perf: no-need-to-sync-before-submit ([`719cdab`](https://github.com/MartinBernstorff/herbarium/commit/719cdab6a18a2107bf29b29ff2885e7807d29886))

* perf: no-need-to-sync-before-submit ([`9426927`](https://github.com/MartinBernstorff/herbarium/commit/94269272c38f0e20bdd081b5cbc40c43d4251101))

### Style

* style: lint ([`568cf53`](https://github.com/MartinBernstorff/herbarium/commit/568cf536d24678597619ee4d6e60ff71508b1838))


## v0.13.0 (2024-01-09)

### Feature

* feat: support new prefix (issue #83) (#85)

feat: support new prefix (issue #83)

Fixes #83

misc.

misc.

misc.

misc. ([`963e7a3`](https://github.com/MartinBernstorff/herbarium/commit/963e7a3a9619cfa175fc286917536f475b46cf23))

* feat: submit descendants when running submit (issue #77) (#82)

feat: submit descendants when running submit (issue #77)

Fixes #77

misc. ([`7b16189`](https://github.com/MartinBernstorff/herbarium/commit/7b161891d843406f626fc47d3cb01b1fc5d0c62e))

* feat: submit descendants when running submit (issue #77)

Fixes #77 ([`40039a4`](https://github.com/MartinBernstorff/herbarium/commit/40039a4ad6acb6c50ee41165f966154264bbbf78))

* feat: restack on sync (issue #78) (#81)

feat: restack on sync (issue #78)

Fixes #78

feat: restack on sync (issue #78)

Fixes #78 ([`572c834`](https://github.com/MartinBernstorff/herbarium/commit/572c83466a1196db463c707bf5a51c0312a97b71))

* feat: restack on sync (issue #78)

Fixes #78 ([`f8f7815`](https://github.com/MartinBernstorff/herbarium/commit/f8f78152136ae44826737a9359d62ace7f9b9f06))

### Fix

* fix: typo ([`1d31e1b`](https://github.com/MartinBernstorff/herbarium/commit/1d31e1bea1923dd903a27a5834fd41807a5ee974))

### Unknown

* misc. ([`4983081`](https://github.com/MartinBernstorff/herbarium/commit/4983081c3c50a1c4324d5b48f422031aa3da68a5))

* misc. ([`8dabb1f`](https://github.com/MartinBernstorff/herbarium/commit/8dabb1fb56f203901cb09572e141652fb6dcbc7a))

* misc. ([`82e5000`](https://github.com/MartinBernstorff/herbarium/commit/82e5000c503cb313998e17dfea31f0fa1f268be7))

* misc. ([`2936338`](https://github.com/MartinBernstorff/herbarium/commit/29363383b33177d094a4cb55e1a55778cadae09a))

* misc. ([`6317036`](https://github.com/MartinBernstorff/herbarium/commit/631703656873e981827509ee3a6bb8f420317da2))

* misc. ([`302d7fe`](https://github.com/MartinBernstorff/herbarium/commit/302d7fe19db0e62e15326649617c9b9e04cf6709))

* misc. ([`4a03f96`](https://github.com/MartinBernstorff/herbarium/commit/4a03f96dbaebafaa5f30b6e846d27f840f602cca))


## v0.12.1 (2024-01-09)

### Fix

* fix: new should create branch from trunk (#80) ([`dcbb496`](https://github.com/MartinBernstorff/herbarium/commit/dcbb496b6383081ecf835a6ed925569377e88b58))

* fix: decrease syncs ([`1a3d21b`](https://github.com/MartinBernstorff/herbarium/commit/1a3d21ba81decee7e4c0dd3c2a2711e75bb7cc09))

* fix: new should create branch from trunk (issue #79)

Fixes #79 ([`50dfa29`](https://github.com/MartinBernstorff/herbarium/commit/50dfa29ab7e11a5cc358dd89651c53cf07d1502f))

### Unknown

* misc. ([`a18907f`](https://github.com/MartinBernstorff/herbarium/commit/a18907f62761a6c87da68ca040e7b451171d1e88))

* misc. ([`6f3e21e`](https://github.com/MartinBernstorff/herbarium/commit/6f3e21e525c6da81f386fec114f14858e72dd5a9))

* misc. ([`2b77a63`](https://github.com/MartinBernstorff/herbarium/commit/2b77a63cd5f272ef387f37454a9a4705bbaceee5))

* misc. ([`94ae390`](https://github.com/MartinBernstorff/herbarium/commit/94ae3904558e2149dc351456bf2cdb475b8911ea))


## v0.12.0 (2024-01-09)

### Feature

* feat: show current stack state after each operation (issue #67) (#76) ([`3ea5b4c`](https://github.com/MartinBernstorff/herbarium/commit/3ea5b4c86662ed8b0a5659ec34cd63660c7b7dbf))


## v0.11.0 (2024-01-09)

### Feature

* feat: show current stack state after each operation (issue #67)

Fixes #67 ([`12292f2`](https://github.com/MartinBernstorff/herbarium/commit/12292f2f65cb87e6b175824b533bd845bea91d46))

* feat: show current stack state after each operation (issue #67)

Fixes #67 ([`541feef`](https://github.com/MartinBernstorff/herbarium/commit/541feef2fa06d795951875bacd2f61384b004cc1))

* feat: add herb status command (issue #69) (#75)

feat: add herb status command (issue #69)

Fixes #69

misc. ([`17d1719`](https://github.com/MartinBernstorff/herbarium/commit/17d17194c925822f494c171ae1592177c34e7071))


## v0.10.1 (2024-01-09)

### Feature

* feat: add herb status command (issue #69)

Fixes #69 ([`a4f6bc3`](https://github.com/MartinBernstorff/herbarium/commit/a4f6bc3462fbcd5be5efaf6d1278ca3c1017c1e4))

### Fix

* fix: remove  from descriptions since they have special meaning in shell (issue #70) (#74)

fix: remove  from descriptions since they have special meaning in shell (issue #70)

Fixes #70

misc. ([`9947474`](https://github.com/MartinBernstorff/herbarium/commit/9947474bafb794fb2d28870f0138f292c1084e9f))

* fix: remove  from descriptions since they have special meaning in shell (issue #70)

Fixes #70 ([`d555127`](https://github.com/MartinBernstorff/herbarium/commit/d5551278d9dea79eba7bf27ce4012ae9f15819fb))

* fix: insert-at-front (issue #68) (#73)

fix: insert-at-front (issue #68)

Fixes #68

misc. ([`1b612be`](https://github.com/MartinBernstorff/herbarium/commit/1b612beca91156d42f20a60eff21f8d432ea7222))

* fix: insert-at-front (issue #68)

Fixes #68 ([`f8488e2`](https://github.com/MartinBernstorff/herbarium/commit/f8488e22797253a5fe8797d2181d537371435938))

### Unknown

* misc. ([`9cbd95c`](https://github.com/MartinBernstorff/herbarium/commit/9cbd95cea209bb99c9581c3cde83a6159474825e))

* misc. ([`13d7208`](https://github.com/MartinBernstorff/herbarium/commit/13d72086969505b1daa392f2a5b26b498ee4d65d))

* misc. ([`c3aa3ad`](https://github.com/MartinBernstorff/herbarium/commit/c3aa3ad9f71a946e8b8f9abb4621273bdef75e4e))

* cli: fix emoji handling in prompt (#58) (#66)

Fixes #58 ([`9c9b8ad`](https://github.com/MartinBernstorff/herbarium/commit/9c9b8adc0f96105a7f7a85cb9d4a940f550e9c28))


## v0.10.0 (2024-01-09)

### Feature

* feat: add issue number to PR title (#65)

feat: add issue number to PR title

feat: add issue number to PR title ([`d3c0437`](https://github.com/MartinBernstorff/herbarium/commit/d3c043795aeb4c3b608a18fe4e69f9fa0292eaba))

* feat: add issue number to PR title ([`6e24ae6`](https://github.com/MartinBernstorff/herbarium/commit/6e24ae6d8671d5a41cf72635c639797075eaa75d))

* feat: add issue number to PR title ([`1800951`](https://github.com/MartinBernstorff/herbarium/commit/1800951e19699a1562a7817f84dfffba6592edda))

### Unknown

* cli: fix emoji handling in prompt (#58)

Fixes #58 ([`2e76529`](https://github.com/MartinBernstorff/herbarium/commit/2e7652948e36f62777f977c6c80678523a6bf911))

* misc. ([`e76cb20`](https://github.com/MartinBernstorff/herbarium/commit/e76cb20df4ea038ebdc31cf467e2140a6fbf1f65))


## v0.9.0 (2024-01-08)

### Feature

* feat: insert at bottom (#61)

feat: insert at bottom

Fixes #51

misc.

misc. ([`3cb9eda`](https://github.com/MartinBernstorff/herbarium/commit/3cb9eda640bc38b7fab4c1c06c96875e3b85cc08))


## v0.8.2 (2024-01-08)

### Feature

* feat: insert at bottom

Fixes #51 ([`fd42fcc`](https://github.com/MartinBernstorff/herbarium/commit/fd42fcc592a8ff2c12f60c93ef57cd07daa14b32))

### Fix

* fix: Fixes in first commit (#60)

fix: Fixes in first commit

fix: Fixes in first commit ([`e69d0d7`](https://github.com/MartinBernstorff/herbarium/commit/e69d0d77f91632bea76fc4adcb68a0921d8a6632))

* fix: Fixes in first commit ([`8341b40`](https://github.com/MartinBernstorff/herbarium/commit/8341b4002f4ce350952942c2cf19a29a90815f0c))

### Style

* style: linting ([`fe5571d`](https://github.com/MartinBernstorff/herbarium/commit/fe5571d1bf4843568062e57062ff5c4c1c09b8cc))

* style: lint ([`249025e`](https://github.com/MartinBernstorff/herbarium/commit/249025ea8555b34554a7ae3844e5a5db206c5ae6))

### Unknown

* misc. ([`5402933`](https://github.com/MartinBernstorff/herbarium/commit/5402933314d9691d87237f0493f8250765ebdcf5))

* misc. ([`f5a2a01`](https://github.com/MartinBernstorff/herbarium/commit/f5a2a0140dc51f86955be51d88a5a62728f6320f))

* misc. ([`87bc825`](https://github.com/MartinBernstorff/herbarium/commit/87bc825a7e31de6e38abfc4d16b4dfcfc80fe162))

* cli: fix emoji handling in prompt

Fixes #{issue.entity_id} ([`4b69473`](https://github.com/MartinBernstorff/herbarium/commit/4b694735d166b83f1cf9c551acf6394d5b77e7bd))

* dev: remove redundant ruff target version ([`ab5534a`](https://github.com/MartinBernstorff/herbarium/commit/ab5534a50a4e2c8a85435fa432daef0fc4047357))

* misc. ([`511cc27`](https://github.com/MartinBernstorff/herbarium/commit/511cc27048ea8cec7c0fa25a7ac1690d4721942a))

* misc. ([`fc57fee`](https://github.com/MartinBernstorff/herbarium/commit/fc57fee4096854fa11cbd1e8d66a417275bbf67f))

* misc. ([`be268a0`](https://github.com/MartinBernstorff/herbarium/commit/be268a0435c2f99d707f079544967adc4e1d02d5))

* cli: fix emoji handling in prompt

Fixes #{issue.entity_id} ([`edd4e74`](https://github.com/MartinBernstorff/herbarium/commit/edd4e74a34c8601b8997084a6d5127b7183fbb64))

* dev: remove redundant ruff target version ([`bf7f6a4`](https://github.com/MartinBernstorff/herbarium/commit/bf7f6a463d85aae7f3a2b1b1a1014c95f42984a2))

* cli: fix emoji handling in prompt (#59)

cli: fix emoji handling in prompt

Fixes #{issue.entity_id}

misc. ([`79392c0`](https://github.com/MartinBernstorff/herbarium/commit/79392c07ba9cb5187327a4513be7778c7e0f61f0))

* misc. ([`1ff09a2`](https://github.com/MartinBernstorff/herbarium/commit/1ff09a2aa12ef7f7e6ec7cfdb9409b10d1b5ac0a))

* dev: remove redundant ruff target version (#63)

dev: remove redundant ruff target version

dev: remove redundant ruff target version ([`3737c4a`](https://github.com/MartinBernstorff/herbarium/commit/3737c4a597e0cc1c40101bc588304d11ca38853b))

* dev: remove redundant ruff target version ([`3149656`](https://github.com/MartinBernstorff/herbarium/commit/31496564ce8afe8be1d3e679faa88bef4be0efb4))

* dev: remove redundant ruff target version ([`0acebcb`](https://github.com/MartinBernstorff/herbarium/commit/0acebcb24fc75f6bb6e5bf52e848fef2bac08c5a))


## v0.8.1 (2024-01-08)

### Fix

* fix: prettier subprocess handling (#57)

fix: prettier subprocess handling

Fixes #{issue.entity_id}

misc. ([`2faa5a2`](https://github.com/MartinBernstorff/herbarium/commit/2faa5a2fc05ca27116099a4761aa83eaf23e8bcf))

* fix: prettier subprocess handling

Fixes #{issue.entity_id} ([`5e4204e`](https://github.com/MartinBernstorff/herbarium/commit/5e4204eed04344cb8ae8db6a01f9fba6c1da0ec0))

### Unknown

* misc. ([`d2edd50`](https://github.com/MartinBernstorff/herbarium/commit/d2edd5065dc6a95ce66aa16292a2c21a52c78828))


## v0.8.0 (2024-01-08)

### Feature

* feat: simplify prompt (#56)

feat: simplify prompt

misc. ([`c017abd`](https://github.com/MartinBernstorff/herbarium/commit/c017abdd64406dc93ca283c3e2846cdc3dfc875d))

* feat: simplify prompt ([`92c1885`](https://github.com/MartinBernstorff/herbarium/commit/92c18850cddbe9d107f6759eed17b008e12cb17a))

### Unknown

* misc. ([`649fe4a`](https://github.com/MartinBernstorff/herbarium/commit/649fe4af6410923a945ba9855045d22b96c326e9))

* misc. (#55) ([`8c91f5c`](https://github.com/MartinBernstorff/herbarium/commit/8c91f5cc75573a84caa45e4e70b17606577d2158))

* misc. ([`f1656a7`](https://github.com/MartinBernstorff/herbarium/commit/f1656a7493273eb93fe867a546ecf599d8247a77))


## v0.7.0 (2024-01-08)

### Feature

* feat: allow manual creation (#53)

feat: allow manual creation

Fixes #20

misc.

misc.

misc.

misc.

misc.

misc. ([`aa7f404`](https://github.com/MartinBernstorff/herbarium/commit/aa7f404b2bbbd59965ea10f3ab92b0561bc83468))

* feat: allow manual creation

Fixes #20 ([`8050c4b`](https://github.com/MartinBernstorff/herbarium/commit/8050c4b7a10f29817dec260100b58f2a2c4a296c))

### Style

* style: linting ([`2f095e1`](https://github.com/MartinBernstorff/herbarium/commit/2f095e1cfb478ddcc9117b9814a034bfbba1bf43))

### Unknown

* misc. ([`ba0a034`](https://github.com/MartinBernstorff/herbarium/commit/ba0a034bfce09b875d3fbcfffa65e78f88113e97))

* misc. ([`d3c75fe`](https://github.com/MartinBernstorff/herbarium/commit/d3c75fec3ad59a2a160ca0f2236f6a943d1cae9f))

* misc. ([`4bccccb`](https://github.com/MartinBernstorff/herbarium/commit/4bccccbd3ba923d8e00c0465a4c8fd07d72a0312))

* misc. ([`13b5811`](https://github.com/MartinBernstorff/herbarium/commit/13b5811285d6e4d66e9574036c79fe14786861be))

* misc. ([`9dd20aa`](https://github.com/MartinBernstorff/herbarium/commit/9dd20aa8fb5909ecc7899ab17dc9b0841c59d163))

* misc. ([`88e8b32`](https://github.com/MartinBernstorff/herbarium/commit/88e8b32c4fecd0af366c87bef521c0d0b0ece832))

* misc. ([`345ec2f`](https://github.com/MartinBernstorff/herbarium/commit/345ec2fc3b379f2016097b48ceebb69976450d23))


## v0.6.0 (2024-01-08)

### Feature

* feat: cleaner issue title parsing (#48) ([`da985b9`](https://github.com/MartinBernstorff/herbarium/commit/da985b91103e8421ca653a448122936e8e0d05ea))

* feat: cleaner issue title parsing

Fixes #16 ([`76821cf`](https://github.com/MartinBernstorff/herbarium/commit/76821cfb833bf16e2f80df519b025a14b3d29304))

### Unknown

* cli: present refresh option when finding issues (#50) ([`3d69629`](https://github.com/MartinBernstorff/herbarium/commit/3d69629d79115793bc490bb4a95552aad238fafe))

* misc. ([`a4300f9`](https://github.com/MartinBernstorff/herbarium/commit/a4300f9d9779cfa9e7566850a32e65a33d737bbf))

* cli: present refresh option when finding issues

Fixes #49 ([`3a6f020`](https://github.com/MartinBernstorff/herbarium/commit/3a6f020c5e274b30e6e3a72dc54ae2cd6a5c3df7))

* misc. ([`a8b9623`](https://github.com/MartinBernstorff/herbarium/commit/a8b96233560dd2d4e92f6d860b221056a1dc507a))


## v0.5.0 (2024-01-08)

### Feature

* feat: pretty error message if no issues assigned (#47)

feat: pretty error message if no issues assigned

Fixes #29

misc.

fix: types ([`84f501e`](https://github.com/MartinBernstorff/herbarium/commit/84f501eb5f27788f546b96809d843b02be8fbaf0))

* feat: pretty error message if no issues assigned

Fixes #29 ([`6087659`](https://github.com/MartinBernstorff/herbarium/commit/608765985b3afb2c82fe85e26e7c07933637148e))

### Fix

* fix: types ([`50ef8e8`](https://github.com/MartinBernstorff/herbarium/commit/50ef8e8ea9465dfc270425921923fc15148f7aee))

### Unknown

* misc. ([`6c195ba`](https://github.com/MartinBernstorff/herbarium/commit/6c195ba50e21f5b9f55e937216b9be266c9ac699))


## v0.4.1 (2024-01-08)

### Ci

* ci: run tests on prs against any branch (#39) ([`e21f947`](https://github.com/MartinBernstorff/herbarium/commit/e21f9477d183d65fd1d7701e691d1c46882a15ef))

* ci: run tests on prs against any branch ([`28c6035`](https://github.com/MartinBernstorff/herbarium/commit/28c603591f7b3037a610a8261c67a14f449aab39))

### Fix

* fix: prettier log

Fixes #35 ([`8e149ba`](https://github.com/MartinBernstorff/herbarium/commit/8e149ba4aa166e439138f027894b41a909798fe2))

### Unknown

* cli: reverse log output (#45)

cli: reverse log output

Fixes #44

cli: reverse log output

Fixes #44 ([`a4faa4b`](https://github.com/MartinBernstorff/herbarium/commit/a4faa4ba49ef31d6e2dad7b95e275b32909b0f72))

* cli: reverse log output

Fixes #44 ([`3d68811`](https://github.com/MartinBernstorff/herbarium/commit/3d6881183f9af53a875e67c9a2521fb9c960b58a))

* misc. ([`5213f14`](https://github.com/MartinBernstorff/herbarium/commit/5213f1453aa956db3bc17f349bdcda8c5b2d22c6))

* misc. ([`428c6ae`](https://github.com/MartinBernstorff/herbarium/commit/428c6aeeb101c1554f5515278829564ad2e73883))

* cli: simplify stack submit animations (#43)

cli: simplify stack submit animations

Fixes #42

misc. ([`d2e44b6`](https://github.com/MartinBernstorff/herbarium/commit/d2e44b60dbe2b96a5c4a7b56d3b0022c321de8a5))

* misc. ([`834beb9`](https://github.com/MartinBernstorff/herbarium/commit/834beb96486e0aee8efabe881543cc462af9db4f))

* dev: submit with automerge (#41)

dev: submit with automerge

Fixes #40

misc. ([`1657a46`](https://github.com/MartinBernstorff/herbarium/commit/1657a46d5e56d4855554458010c1da773e026451))

* misc. ([`0b43842`](https://github.com/MartinBernstorff/herbarium/commit/0b43842cf145ba29421fd2521cf8cc24b23ef326))

* dev: submit with automerge

Fixes #40 ([`144e52c`](https://github.com/MartinBernstorff/herbarium/commit/144e52ca324fc353070af6f2926fc74d7eb1e848))


## v0.4.0 (2024-01-08)

### Feature

* feat: delete unused branches on submit (#37)

feat: delete unused branches on submit

Fixes #30

misc.

fix: even prettier logs ([`45d6a50`](https://github.com/MartinBernstorff/herbarium/commit/45d6a50f0d7238790d0b657594987c1b678c648d))


## v0.3.1 (2024-01-08)

### Fix

* fix: prettier log (#36)

fix: prettier log

Fixes #35

fix: prettier log

Fixes #35 ([`4482f2c`](https://github.com/MartinBernstorff/herbarium/commit/4482f2c9dda485cc006ab5b299f412525a1eabc5))


## v0.3.0 (2024-01-08)

### Feature

* feat: newline after submitting stack to get log pretty (#34)

feat: newline after submitting stack to get log pretty

Fixes #31

misc. ([`99de3de`](https://github.com/MartinBernstorff/herbarium/commit/99de3ded14a272fe85e2e2a68a0e7ce555305a3f))

* feat: make automerge a command-line argument (#33)

Fixes #32 ([`6ecac7f`](https://github.com/MartinBernstorff/herbarium/commit/6ecac7f1ae9a2829d2696b0af8e226997e476ecc))


## v0.2.0 (2024-01-08)

### Feature

* feat: support python &gt;=3.9 (#28)

feat: support python &gt;=3.9

Fixes #27

feat: support python &gt;=3.9

Fixes #27

misc.

misc.

misc. ([`61d9402`](https://github.com/MartinBernstorff/herbarium/commit/61d9402f6601fbe85c6a6c2bec04d6211a4f8007))


## v0.1.0 (2024-01-07)

### Ci

* ci: fix release pipeline ([`e28c77c`](https://github.com/MartinBernstorff/herbarium/commit/e28c77ca98d35733ae3309265bc8d73d6ca9afe5))

* ci: setup release to pypi (#24)

ci: setup release to pypi

Fixes #21

ci: setup release to pypi

Fixes #21

tests: get tests running

misc.

ci: setup release.yml ([`3106412`](https://github.com/MartinBernstorff/herbarium/commit/3106412b885c832f12feaa75c1dc5d16c0088292))

### Feature

* feat: add GithubIssueService

Fixes #8. ([`c2939c3`](https://github.com/MartinBernstorff/herbarium/commit/c2939c3e12247e255293837076643fd6ae811451))

### Unknown

* misc. ([`79f4f2d`](https://github.com/MartinBernstorff/herbarium/commit/79f4f2df5ae0960c0ef15fb96f18ea30eb1eafc5))

* misc. ([`3ad9517`](https://github.com/MartinBernstorff/herbarium/commit/3ad95172a8addfe265cca73cef58c9ee69e5eae2))

* dev: create github cli dir on devcontainer init ([`58c40e6`](https://github.com/MartinBernstorff/herbarium/commit/58c40e6f34e14a1192a6ff177a53f5f417825ab8))

* misc. ([`8de39ac`](https://github.com/MartinBernstorff/herbarium/commit/8de39ac6cb6d45ab0c7066fa18553a4b7a2bade3))

* $feat: pretty cli animations with typer/rich (#23)

$feat: pretty cli animations with typer/rich

Fixes #13

$feat: pretty cli animations with typer/rich

Fixes #13

misc.

misc. ([`830040c`](https://github.com/MartinBernstorff/herbarium/commit/830040c8ec929215791ec495332ebefcc1eca7bd))

* dev: clean up gitignore (#22)

Fixes #19 ([`a58c808`](https://github.com/MartinBernstorff/herbarium/commit/a58c808497b99ee460ad38e840ed658a1a2d93f9))

* $fix: misc. types (#17)

$fix: misc. types

Fixes #14

$fix: misc. types

Fixes #14

refactor: cleanup

misc. ([`4342005`](https://github.com/MartinBernstorff/herbarium/commit/43420050f810d0bad2e6b85708d6d4449140e1c4))

* misc. ([`9d6b6de`](https://github.com/MartinBernstorff/herbarium/commit/9d6b6ded5bd4a56f0fa2f4731c65ef02d4e32ad1))

* Update README.md (#12) ([`f2d76a0`](https://github.com/MartinBernstorff/herbarium/commit/f2d76a05372650b192b47205bca60a3803549762))

* first commit ([`5af600e`](https://github.com/MartinBernstorff/herbarium/commit/5af600e2b31b082b6785271c806243553de5e7bf))
